@@ -397,8 +397,10 @@ def hdsky_upload(web,file1,record_path,qbinfo,basic):
             checknum=int(basic['check'])
         except:
             logger.warning('check参数设置错误')
-        if num==1:
+        if checknum==1:
             a=input('是否确认发布，如果确认请回车，不发布请手动结束程序或者关闭终端')
+        else:
+            logger.info('check参数不为1,正常发布')
     else:
         logger.info('未检测到check参数，正常发布')
         
